/***************************************************************************
 *   Copyright (C) 2006-2007 by Vladimir Jary   *
 *   jaryv1@kmlinux.fjfi.cvut.cz   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

/*!
* \file videoform.ui.h
* \brief Dialog for inserting videos into queue
*
* Allows user to add new videos into queue and edit video tags (for example
* title, artist)
*/

/*!
* \class videoForm
* \brief Video properties dialog
*
* Allows user to add new videos into queue and edit video tags (for example
* title, artist)
*/

/*!
* Called from form constructor, it initializes video open dialog's default working directory
* to user's home
*/
void videoForm::init()
{
	lastDir = QDir::homeDirPath();
}

/*!
* \brief Displays open video dialog
*
* Shows dialog for loading video file. If accepted, it updates apropriate form field.
*/
void videoForm::locateFile()
{
	QString fileName = QFileDialog::getOpenFileName(
                    lastDir,
                    tr("Videos (*.mpg *.mpeg *.mpeg2 *.dv);;Any files (*)"),
                    this,
                    "open file dialog",
                    tr("Select source file") );
	//Accepted
	if(!fileName.isEmpty())
	{
		editFileName->setText(fileName);
		lastDir = fileName;
	}
}


/*!
* \brief Notifies main form about inserted video
* 
* This slot is called when user presses Insert button on form. Video tags
* are read from form fields and are sent to main form using signal.
*/
void videoForm::insert()
{
	QString label = editFileName->text();
	if(label.isEmpty())
	{
		QMessageBox::information( this, tr("Insert video"),
tr("Please, select video file.") );
		return;
	}
	//prepare tags
	QStringList tags;
	tags << editFileName->text();
	tags << editArtist->text();
	tags << editTitle->text();
	tags << editDate->text();
	tags << editLocation->text();
	tags << editOrganization->text();
	tags << editCopyright->text();
	tags << editLicence->text();
	//emit signal
	emit inserted(tags);
	editFileName->setText(QString::null);
}
